# coding: utf-8

"""
    Mentortools Landing Page API

    Mentortools service for building and publishing landing pages

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from landing_page_server_connector.models.landing_history_get import LandingHistoryGet  # noqa: E501

class TestLandingHistoryGet(unittest.TestCase):
    """LandingHistoryGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LandingHistoryGet:
        """Test LandingHistoryGet
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LandingHistoryGet`
        """
        model = LandingHistoryGet()  # noqa: E501
        if include_optional:
            return LandingHistoryGet(
                html = '',
                css = '',
                js = '',
                components = landing_page_server_connector.models.components.Components(),
                styles = [
                    None
                    ],
                assets = [
                    None
                    ],
                theme = landing_page_server_connector.models.theme.Theme(),
                id = 56,
                created_at = 56
            )
        else:
            return LandingHistoryGet(
                html = '',
                css = '',
                js = '',
                components = landing_page_server_connector.models.components.Components(),
                styles = [
                    None
                    ],
                assets = [
                    None
                    ],
                id = 56,
                created_at = 56,
        )
        """

    def testLandingHistoryGet(self):
        """Test LandingHistoryGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
